==> agregado-6.x-1.2.tar.gz: agregado/node.tpl.php <==
<div id="node-<?php print $node->nid; ?>" class="node<?php if ($sticky) { print ' sticky'; } ?><?php if (!$status) { print ' node-unpublished'; } ?> <?php print $type ?> <?php if ($teaser) { print ' teaser'; } ?> <?php print $zebra ?> clear-block">
  <?php print $picture ?>

  <?php if (!$page): ?>
    <?php if ($teaser && user_access('administer nodes')): ?>
      <div class="quick-edit-links">
        <ul class="links inline">
          <li class="first quick-edit"><?php print l('[Edit]', 'node/' . $nid . '/edit'); ?></li>
          <li class="last quick-delete"><?php print l('[Delete]', 'node/' . $nid . '/delete'); ?></li>
        </ul>
      </div>
    <?php endif; ?>

    <h2 class="title"><a href="<?php print $node_url ?>" title="<?php print $title ?>"><?php print $title ?></a></h2>
  <?php endif; ?>

  <div class="meta">
    <?php if ($submitted): ?>
      <span class="submitted">Posted by <?php print $name ?> on <?php print format_date($created, 'custom', 'D, j F, Y - H:i'); ?> &#8211; </span>

      <?php if ($comment == 1 || $comment == 2) { /* Read more and Read/write comment settings */
            if ($node->comment_count == 0) {
              print '<span class="comment-count">No comments</span>';
            } elseif ($node->comment_count == 1) {
              print '<span class="comment-count">1 comment</span>';
            } else {
              print '<span class="comment-count">' . $node->comment_count . ' comments</span>';
            }
        } else {
          print 'Comments disabled';
        }
      ?>

      <?php if ($sticky) { print '<span class="sticky"><img src="' . base_path() . path_to_theme() . '/images/sticky-icon.png" alt="Sticky" title="Sticky" /></span>'; } ?>
    <?php endif; ?>

    <?php if ($terms): ?><div class="terms">Tags: <?php print $terms ?></div><?php endif;?>
  </div>

  <div class="content">
    <?php print $content ?>
  </div>

  <div class="links">
    <?php print $links; ?>
  </div>
</div>

==> agregado-6.x-1.3.tar.gz: agregado/node.tpl.php <==
<div id="node-<?php print $node->nid; ?>" class="node<?php if ($sticky) { print ' sticky'; } ?><?php if (!$status) { print ' node-unpublished'; } ?> <?php print $type ?> <?php if ($teaser) { print ' teaser'; } ?> <?php print $zebra ?> clear-block">
  <?php print $picture ?>

  <?php if (!$page): ?>
    <?php if ($teaser && user_access('administer nodes')): ?>
      <div class="quick-edit-links">
        <ul class="links inline">
          <li class="first quick-edit"><?php print l('[Edit]', 'node/' . $nid . '/edit'); ?></li>
          <li class="last quick-delete"><?php print l('[Delete]', 'node/' . $nid . '/delete'); ?></li>
        </ul>
      </div>
    <?php endif; ?>

    <h2 class="title"><a href="<?php print $node_url ?>" title="<?php print $title ?>"><?php print $title ?></a></h2>
  <?php endif; ?>

  <div class="meta">
    <?php if ($submitted): ?>
      <span class="submitted"><?php print t('Posted by') . ' ' . $name . ' ' . t('on') . format_date($created, 'custom', 'D, j F, Y - H:i'); ?> &#8211; </span>

      <?php if ($comment == 1 || $comment == 2) { /* Read only or Read/write comment settings */
            if ($node->comment_count == 0) {
              print '<span class="comment-count">' . t('No comments') . '</span>';
            } elseif ($node->comment_count == 1) {
              print '<span class="comment-count">' . t('1 comment') . '</span>';
            } else {
              print '<span class="comment-count">' . $node->comment_count . ' ' . t('comments') . '</span>';
            }
        } else {
          print t('Comments disabled');
        }
      ?>

      <?php if ($sticky) { print '<span class="sticky"><img src="' . base_path() . path_to_theme() . '/images/sticky-icon.png" alt="Sticky" title="Sticky" /></span>'; } ?>
    <?php endif; ?>

    <?php if ($terms): ?><div class="terms">Tags: <?php print $terms ?></div><?php endif;?>
  </div>

  <div class="content">
    <?php print $content ?>
  </div>

  <div class="links">
    <?php print $links; ?>
  </div>
</div>
